@@ -1,5 +1,5 @@
 ##
-##  PURPOSE:   Convert fitted distribution of Y=log(T) into distribution of T
+##  PURPOSE:   Convert fitted distribution of Y=trans(T) into distribution of T=itrans(Y)
 ##             * method for objects of class NMixPredCDFMarg
 ##
 ##  AUTHOR:    Arnost Komarek (LaTeX: Arno\v{s}t Kom\'arek)
@@ -14,10 +14,17 @@
 ## *************************************************************
 ## Y2T.NMixPredCDFMarg
 ## *************************************************************
-Y2T.NMixPredCDFMarg <- function(x, ...)
+Y2T.NMixPredCDFMarg <- function(x, itrans=exp, ...)
 {
-  ### Unlog the grids and get T = exp(Y)
-  x$x <- lapply(x$x, exp)
-
+  ### Untrans the grids and get T = itrans(Y)  
+  if (length(itrans) == 1){  
+    x$x <- lapply(x$x, itrans)
+  }else{
+    if (length(itrans) != length(x$x)) stop(paste("itrans must be of length ", length(x$x), sep=""))
+    for (i in 1:length(x$dens)){
+      x$x[[i]] <- itrans[[i]](x$x[[i]])
+    }    
+  }  
+    
   return(x)
 }  
